"use strict";

/**
 * This file is injected to the Growmatik admin page only.
 */

(function ($) {
	var $wrap = $(".wrap");

	/**
  * Utility function to call a simple admin-ajax action.
  *
  * @param {string} action
  * @param {boolean} reload
  * @param {function} callback
  */
	function ajaxAction(action) {
		var _ref = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
		    _ref$reload = _ref.reload,
		    reload = _ref$reload === undefined ? true : _ref$reload,
		    _ref$callback = _ref.callback,
		    callback = _ref$callback === undefined ? null : _ref$callback;

		$.post(ajaxurl, {
			action: action,
			nonce: growmatik.nonce
		}, function (res) {
			if (res.success && reload) {
				document.location.reload();
			}
			if (callback) {
				callback(res);
			}
		});
	}

	/**
  * Confirmation dialog creation utility function
  */
	var createDialog = function createDialog(selector, options) {
		options = $.extend({
			resizable: false,
			modal: true,
			autoOpen: false,
			draggable: false,
			dialogClass: "growmatik-dialog-wrapper",
			width: 400
		}, options || {});

		options.create = function () {
			var instance = $(this);

			instance.siblings(".ui-dialog-titlebar").remove();

			instance.find(".growmatik-dialog-close").click(function (event) {
				event.preventDefault();
				instance.dialog("close");
			});

			$(document).on("click", ".ui-widget-overlay", function () {
				instance.dialog("close");
			});
		};

		var dialog = $(selector).dialog(options);
		dialog.data("uiDialog")._focusTabbable = $.noop;

		return dialog;
	};

	/**
  * Disconnect button
  */
	$(".growmatik-disconnect-confirm").on("click", function (event) {
		event.preventDefault();

		var disconnectConfirmDialog = createDialog("#growmatik-disconnect-dialog");
		disconnectConfirmDialog.dialog("open");
	});

	/**
  * Perform disconnect
  */
	$("#growmatik-disconnect-dialog").on("click", ".growmatik-remove-integration", function (e) {
		e.preventDefault();
		ajaxAction("growmatik_remove_integration");
	});

	/**
  * Erase Data button
  */
	$(".growmatik-destroy-data-confirm").on("click", function (event) {
		event.preventDefault();

		var eraseConfirmDialog = createDialog("#growmatik-destroy-data-dialog");
		eraseConfirmDialog.dialog("open");
	});

	/**
  * Perform erase data
  */
	$("#growmatik-destroy-data-dialog").on("click", ".growmatik-destroy-data", function (e) {
		e.preventDefault();
		ajaxAction("growmatik_destroy_data");
	});

	/**
  * Perform pause
  */
	$wrap.on("click", ".growmatik-pause-integration", function (event) {
		event.preventDefault();
		ajaxAction("growmatik_pause_integration");
	});

	/**
  * Perform resume
  */
	$wrap.on("click", ".growmatik-resume-integration", function (event) {
		event.preventDefault();
		ajaxAction("growmatik_resume_integration");
	});

	if (['In Progress', 'Error'].includes($("#admin-sync-status").text())) {
		var intervalId = void 0;

		var responseHandler = function responseHandler(response) {
			if (response.success && response.level) {
				clearInterval(intervalId);
				document.location.reload();
			}
		};

		var intervalTime = 5000;
		if ($("#admin-sync-status").text() == 'Error') {
			intervalTime = 60000;
		}

		intervalId = window.setInterval(function () {
			ajaxAction("growmatik_get_health_level", {
				reload: false,
				callback: responseHandler
			});
		}, intervalTime);
	}

	/**
  * EU Consent
  */

	$('.growmatik-help-icon').tooltip();

	$wrap.on('click', '#growmatik-save-settings', function (event) {
		event.preventDefault();

		var saveBtn = document.getElementById('growmatik-save-settings');
		saveBtn.disabled = 'disabled';

		var data = {
			action: 'growmatik_save_settings',
			nonce: growmatik.nonce
		};

		var $inputs = document.querySelectorAll('input[name^="growmatik_consent_"]');
		$inputs.forEach(function (input) {
			data[input.name] = input.checked;
		});

		data['growmatik_consent_statement'] = document.getElementById('growmatik_consent_statement').value;

		var $span = document.createElement('span');
		$span.classList.add('growmatik-results');

		$.post(ajaxurl, data, function (res) {
			saveBtn.removeAttribute('disabled');

			if (res && res.success) {
				$span.classList.add('success');
				$span.innerText = growmatik.success_message;
			} else {
				$span.classList.add('error');
				$span.innerText = growmatik.erorr_message;
			}

			saveBtn.insertAdjacentElement('afterend', $span);
			setTimeout(function () {
				$span.innerText = '';
				$span.classList.remove('error', 'success');
			}, 1000);
		});
	});
})(jQuery);