<?php

namespace Growmatik\Admin;

class Init {

	/** @var string  */
	const HOOK_SUFFIX = 'settings_page_growmatik-admin';

	public function __construct() {
		add_action( 'admin_init', array( $this, 'activation_redirect' ) );
		add_action( 'admin_menu', array( $this, 'add_options_page' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_assets' ) );
		add_action( 'admin_init', array( $this, 'feedback' ) );
		new Email_Consent();
	}

	public function feedback() {
		new \Growmatik\Admin\Feedback();
	}

	public function add_options_page() {
		add_options_page(
			esc_html__( 'Growmatik Settings', 'growmatik' ),
			esc_html__( 'Growmatik', 'growmatik' ),
			'manage_options',
			'growmatik-admin',
			array( $this, 'render_option_page' )
		);
	}

	/** @define "GROWMATIK_ADMIN_PATH" "" */
	public function render_option_page() {

		if ( Integration::is_integrated() ) {
			include_once GROWMATIK_ADMIN_PATH . 'views/integrated.php';
		} else {
			include_once GROWMATIK_ADMIN_PATH . 'views/welcome.php';
		}
	}

	public function enqueue_assets( $hook ) {
		// WordPress admin dashboard AND Growmatik admin page
		if ( self::HOOK_SUFFIX === $hook || 'index.php' === $hook ) {
			wp_enqueue_script( 'growmatik-wordpress-dashboard' );

			$params = array(
				'nonce' => wp_create_nonce( 'growmatik_ajax' ),
			);

			wp_localize_script( 'growmatik-wordpress-dashboard', 'growmatik', $params );

		}

		// Growmatik admin page
		if ( self::HOOK_SUFFIX === $hook ) {
			wp_enqueue_script( 'growmatik-admin' );
			wp_enqueue_style( 'growmatik-admin' );

			$params = array(
				'nonce'           => wp_create_nonce( 'growmatik_ajax' ),
				'success_message' => __( 'Saved!', 'growmatik' ),
				'error_message'   => __( 'Error!', 'growmatik' ),
			);

			wp_localize_script( 'growmatik-admin', 'growmatik', $params );
		}
	}

	public function activation_redirect() {
		if ( ! get_transient( 'growmatik_activation_redirect' ) ) {
			return;
		}

		if ( wp_doing_ajax() ) {
			return;
		}

		delete_transient( 'growmatik_activation_redirect' );

		// phpcs:ignore WordPress.Security.NonceVerification.Recommended
		if ( is_network_admin() || isset( $_GET['activate-multi'] ) ) {
			return;
		}

		wp_safe_redirect( self::growmatik_admin_url() );

		exit;
	}

	/**
	 * Returns growmatik admin page URL.
	 *
	 * @return string
	 */
	public static function growmatik_admin_url() {
		return admin_url( 'options-general.php?page=growmatik-admin' );
	}
}
