<?php

namespace Growmatik;

class Assets_Manager {

	public $suffix = '.min';

	public function __construct() {
		add_action( 'wp_enqueue_scripts', array( $this, 'register_public_assets' ), 5 );
		add_action( 'admin_enqueue_scripts', array( $this, 'register_admin_assets' ), 9 );
		add_action( 'wp_head', array( $this, 'prefetch_dns' ), 1 );

		if ( $this->is_script_debug() ) {
			$this->suffix = '';
		}
	}

	public static function is_script_debug() {
		return defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG;
	}

	public function register_public_assets() {
		$this->register_public_scripts();
	}

	public function register_public_scripts() {
		$site_id = get_option( 'growmatik_site_id', false );
		if ( ! $site_id ) {
			return;
		}

		$automations_url = GROWMATIK_API_URL . '/dynamic/sites/' . $site_id . '/automations.js';

		if ( 'guest' !== \Growmatik\get_user_type() ) {
			$user_id = get_current_user_id();
			if ( $user_id ) {
				$automations_url = add_query_arg( 'userId', $user_id, $automations_url );
			}
		}

		wp_register_script( 'growmatik-automations', $automations_url, array(), GROWMATIK_VERSION, false );
		wp_register_script( 'growmatik-if-then', GROWMATIK_RULE_CLIENT_URL, array( 'jquery', 'growmatik-automations' ), GROWMATIK_VERSION, false );
	}

	public function register_admin_assets() {
		$this->register_admin_scripts();
		$this->register_admin_styles();
	}

	public function register_admin_scripts() {
		wp_register_script(
			'growmatik-admin',
			GROWMATIK_ADMIN_ASSETS . 'js/growmatik-admin' . $this->suffix . '.js',
			array( 'jquery', 'jquery-ui-dialog', 'jquery-ui-tooltip' ),
			GROWMATIK_VERSION,
			true
		);

		wp_register_script(
			'growmatik-wordpress-dashboard',
			GROWMATIK_ADMIN_ASSETS . 'js/growmatik-wordpress-dashboard' . $this->suffix . '.js',
			array( 'jquery' ),
			GROWMATIK_VERSION,
			true
		);

		wp_register_script(
			'growmatik-feedback',
			GROWMATIK_ADMIN_ASSETS . 'js/growmatik-feedback' . $this->suffix . '.js',
			array( 'jquery', 'jquery-ui-dialog' ),
			GROWMATIK_VERSION,
			true
		);
	}

	public function register_admin_styles() {
		wp_register_style(
			'growmatik-admin',
			GROWMATIK_ADMIN_ASSETS . 'css/growmatik-admin' . $this->suffix . '.css',
			array( 'wp-jquery-ui-dialog' ),
			GROWMATIK_VERSION,
			'all'
		);

		wp_register_style(
			'growmatik-feedback',
			GROWMATIK_ADMIN_ASSETS . 'css/growmatik-feedback' . $this->suffix . '.css',
			array( 'wp-jquery-ui-dialog' ),
			GROWMATIK_VERSION,
			'all'
		);
	}

	public function prefetch_dns() {
		$site_id = get_option( 'growmatik_site_id', false );

		if ( $site_id ) {
			echo '<link rel="dns-prefetch" href="//api.' . esc_attr( GROWMATIK_SUFFIX ) . '" />';
		}
	}
}
